==> aliyun-java-sdk-ram-3.3.1-sources.jar: com/aliyuncs/ram/model/v20150501/CreateRoleRequest.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.aliyuncs.ram.model.v20150501;

import com.aliyuncs.RpcAcsRequest;
import com.aliyuncs.http.ProtocolType;
import com.aliyuncs.http.MethodType;
import com.aliyuncs.ram.Endpoint;

/**
 * @author auto create
 * @version 
 */
public class CreateRoleRequest extends RpcAcsRequest<CreateRoleResponse> {
	   

	private String description;

	private String assumeRolePolicyDocument;

	private Long maxSessionDuration;

	private String roleName;
	public CreateRoleRequest() {
		super("Ram", "2015-05-01", "CreateRole", "Ram");
		setProtocol(ProtocolType.HTTPS);
		setMethod(MethodType.POST);
		try {
			com.aliyuncs.AcsRequest.class.getDeclaredField("productEndpointMap").set(this, Endpoint.endpointMap);
			com.aliyuncs.AcsRequest.class.getDeclaredField("productEndpointRegional").set(this, Endpoint.endpointRegionalType);
		} catch (Exception e) {}
	}

	public String getDescription() {
		return this.description;
	}

	public void setDescription(String description) {
		this.description = description;
		if(description != null){
			putQueryParameter("Description", description);
		}
	}

	public String getAssumeRolePolicyDocument() {
		return this.assumeRolePolicyDocument;
	}

	public void setAssumeRolePolicyDocument(String assumeRolePolicyDocument) {
		this.assumeRolePolicyDocument = assumeRolePolicyDocument;
		if(assumeRolePolicyDocument != null){
			putQueryParameter("AssumeRolePolicyDocument", assumeRolePolicyDocument);
		}
	}

	public Long getMaxSessionDuration() {
		return this.maxSessionDuration;
	}

	public void setMaxSessionDuration(Long maxSessionDuration) {
		this.maxSessionDuration = maxSessionDuration;
		if(maxSessionDuration != null){
			putQueryParameter("MaxSessionDuration", maxSessionDuration.toString());
		}
	}

	public String getRoleName() {
		return this.roleName;
	}

	public void setRoleName(String roleName) {
		this.roleName = roleName;
		if(roleName != null){
			putQueryParameter("RoleName", roleName);
		}
	}

	@Override
	public Class<CreateRoleResponse> getResponseClass() {
		return CreateRoleResponse.class;
	}

}

==> aliyun-java-sdk-ram-3.3.3-sources.jar: com/aliyuncs/ram/model/v20150501/CreateRoleRequest.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.aliyuncs.ram.model.v20150501;

import com.aliyuncs.RpcAcsRequest;
import java.util.List;
import com.google.gson.Gson;
import com.google.gson.annotations.SerializedName;
import com.aliyuncs.http.ProtocolType;
import com.aliyuncs.http.MethodType;
import com.aliyuncs.ram.Endpoint;

/**
 * @author auto create
 * @version 
 */
public class CreateRoleRequest extends RpcAcsRequest<CreateRoleResponse> {
	   

	private String description;

	private String assumeRolePolicyDocument;

	@SerializedName("tag")
	private List<Tag> tag;

	private Long maxSessionDuration;

	private String roleName;
	public CreateRoleRequest() {
		super("Ram", "2015-05-01", "CreateRole", "ram");
		setProtocol(ProtocolType.HTTPS);
		setMethod(MethodType.POST);
		try {
			com.aliyuncs.AcsRequest.class.getDeclaredField("productEndpointMap").set(this, Endpoint.endpointMap);
			com.aliyuncs.AcsRequest.class.getDeclaredField("productEndpointRegional").set(this, Endpoint.endpointRegionalType);
		} catch (Exception e) {}
	}

	public String getDescription() {
		return this.description;
	}

	public void setDescription(String description) {
		this.description = description;
		if(description != null){
			putQueryParameter("Description", description);
		}
	}

	public String getAssumeRolePolicyDocument() {
		return this.assumeRolePolicyDocument;
	}

	public void setAssumeRolePolicyDocument(String assumeRolePolicyDocument) {
		this.assumeRolePolicyDocument = assumeRolePolicyDocument;
		if(assumeRolePolicyDocument != null){
			putQueryParameter("AssumeRolePolicyDocument", assumeRolePolicyDocument);
		}
	}

	public List<Tag> getTag() {
		return this.tag;
	}

	public void setTag(List<Tag> tag) {
		this.tag = tag;	
		if (tag != null) {
			putQueryParameter("Tag" , new Gson().toJson(tag));
		}	
	}

	public Long getMaxSessionDuration() {
		return this.maxSessionDuration;
	}

	public void setMaxSessionDuration(Long maxSessionDuration) {
		this.maxSessionDuration = maxSessionDuration;
		if(maxSessionDuration != null){
			putQueryParameter("MaxSessionDuration", maxSessionDuration.toString());
		}
	}

	public String getRoleName() {
		return this.roleName;
	}

	public void setRoleName(String roleName) {
		this.roleName = roleName;
		if(roleName != null){
			putQueryParameter("RoleName", roleName);
		}
	}

	public static class Tag {

		@SerializedName("Value")
		private String value;

		@SerializedName("Key")
		private String key;

		public String getValue() {
			return this.value;
		}

		public void setValue(String value) {
			this.value = value;
		}

		public String getKey() {
			return this.key;
		}

		public void setKey(String key) {
			this.key = key;
		}
	}

	@Override
	public Class<CreateRoleResponse> getResponseClass() {
		return CreateRoleResponse.class;
	}

}
